logistic_table_edc <- function(modsumm){
  df <- as.data.frame(modsumm)
  df <- df[-1, ] #remove intercept
  df[] <- lapply(df, function(x) if(is.numeric(x)) format(round(x, 3), nsmall=3) else x)
  df$CI <- paste0("(", df$`2.5 %`, ", ", df$`97.5 %`, ")")
  df$Variable <- c("Age (per year)", "Education (0-7 years vs. 8+ years)", "Race (Black/Brown/Indigenous vs. All Other)", 
                   "Region (Midwest vs. Southeast)", "Region (North vs. Southeast)", "Region (Northeast vs. Southeast)", "Region (South vs. Southeast)", 
                   "Years since ART initiation at EDC", "Years since HIV diagnosis at EDC", "CD4 at conception", "VL below detection limit (Yes vs. No)", 
                   "Diabetes (Yes vs. No)", "Epilepsy or antiepileptic medication use (Yes vs. No)", "Tobacco use (Yes vs. No)", "Alcohol use (Yes vs. No)",
                   "Crack/cocaine use (Yes vs. No)", "Number of previous pregnancies", "Adverse pregnancy outcomes (Yes vs. No)", "BMI at conception", "Folic acid use (Yes vs. No)")
  df <- df[c("Variable", "estimate", "CI", "std.error", "p.value")]
  names(df) <- c("Variable", "OR", "CI", "SE", "p")
  df$p <- ifelse(df$p <.001, "<.001", df$p)
  rownames(df) <- NULL
  df}


logistic_table_edc_pre <- function(modsumm){
  df <- as.data.frame(modsumm)
  df <- df[-1, ] #remove interacept
  df[] <- lapply(df, function(x) if(is.numeric(x)) format(round(x, 3), nsmall=3) else x)
  df$CI <- paste0("(", df$`2.5 %`, ", ", df$`97.5 %`, ")")
  df$Variable <- c("Age (per year)", "Education (0-7 years vs. 8+ years)", "Race (Black/Brown/Indigenous vs. All Other)", 
               "Region (Midwest vs. Southeast)", "Region (North vs. Southeast)", "Region (Northeast vs. Southeast)", "Region (South vs. Southeast)", 
               "Years since ART initiation at EDC", "Years since HIV diagnosis at EDC", "CD4 at conception", "VL below detection limit (Yes vs. No)", 
               "Epilepsy or antiepileptic medication use (Yes vs. No)", "Tobacco use (Yes vs. No)", "Alcohol use (Yes vs. No)",
               "Crack/cocaine use (Yes vs. No)", "Number of previous pregnancies", "Adverse pregnancy outcomes (Yes vs. No)", "BMI at conception", "Any folic acid use (Yes vs. No)",
               "Number of prenatal visits (<6 vs. >=6)", "Syphilis (Yes vs. No)", "Any diabetes (Yes vs. No)", "Gestational hypertension (Yes vs. No)", "Average weight gain per week")  
  df <- df[c("Variable", "estimate", "CI", "std.error", "p.value")]
  names(df) <- c("Variable", "OR", "CI", "SE", "p")
  df$p <- ifelse(df$p <.001, "<.001", df$p)
  rownames(df) <- NULL
  df}



logistic_table_outcome <- function(moddf, sandwichse){
  moddf <- as.data.frame(moddf)
  moddf <- moddf[-1, ] #take out standard error and replace with robust s.e., take out intercept
  moddf$std.error <- sandwichse$se.mi[2]
  moddf[] <- lapply(moddf, function(x) if(is.numeric(x)) format(round(x, 3), nsmall=3) else x)
  moddf$CI <- paste0("(", moddf$`2.5 %`, ", ", moddf$`97.5 %`, ")")
  moddf <- moddf[, -c(3, 4, 6, 7)] # take out statistic, 2.5. 97.5
  moddf$Variable <- "DTG at conception (Yes vs. No)"
  names(moddf) <- c("OR", "SE", "p", "CI", "Variable")
  moddf <- moddf[c("Variable", "OR", "CI", "SE", "p")]
  rownames(moddf) <- NULL
  moddf$p <- ifelse(moddf$p <.001, "<.001", moddf$p)
  moddf
}

boot_mi_table <- function(myboot){
table <- data.frame(OR= exp(myboot$q.mi), SE= myboot$se.mi, 
                       LCI= exp(myboot$q.mi + qt(.025,df=R)*myboot$se.mi),
                       UCI=exp(myboot$q.mi + qt(.975,df=R)*myboot$se.mi),
                       p= 2*pnorm(0, abs(myboot$q.mi), myboot$se.mi))
colnames(table) <- c("OR", "SE", "LCI", "UCI", "p")
table[] <- lapply(table, function(x) if(is.numeric(x)) format(round(x, 3), nsmall=3) else x)
table$CI <- paste0("(", table$LCI, ", ", table$UCI, ")")
table$Variable <- "DTG at conception (Yes vs. No)"
table <- table[c("Variable", "OR", "CI", "SE", "p")]
table
}

boot_mi_table2 <- function(myboot){
  table <- data.frame(OR= exp(myboot$q.mi), SE= myboot$se.mi, 
                      LCI= exp(myboot$q.mi + qt(.025,df=R)*myboot$se.mi),
                      UCI=exp(myboot$q.mi + qt(.975,df=R)*myboot$se.mi),
                      p= 2*pnorm(0, abs(myboot$q.mi), myboot$se.mi))
  colnames(table) <- c("OR", "SE", "LCI", "UCI", "p")
  table[] <- lapply(table, function(x) if(is.numeric(x)) format(round(x, 3), nsmall=3) else x)
  table$CI <- paste0("(", table$LCI, ", ", table$UCI, ")")
  table$Variable <- "DTG/RAL at conception (Yes vs. No)"
  table <- table[c("Variable", "OR", "CI", "SE", "p")]
  table
}